@@ -1,5 +1,5 @@
 """Top-level package for clatmenow."""
 
 __author__ = """Taylor Monacelli"""
-__email__ = 'taylormonacelli@gmail.com'
-__version__ = '0.1.0'
+__email__ = "taylormonacelli@gmail.com"
+__version__ = "0.1.1"
